const lifecycle = require('./lifecycle');
const methods = require('./methods');
const utility = require('./utility');
const schema = require('./schema');

/**
 * Generates a generic SQL connector for API Builder.
 * @param {sting} path - The path to the connector index.js.
 * @param {sting} dialect - The type of connector to generate. Can be one of:
 * pg, sqlite3, mysql, oracle, mssql.
 * @param {object} utilities - Additional utility functions exported from the
 * connector.
 * @param {object} utilities.convertColumnToField - A utility to convert a DB
 * column to a Model field.
 * @returns {Object} The connector object.
 */
module.exports = function (path, dialect, utilities) {
	return {
		/**
		 * A generic SQL connector for API Builder.
		 * @param {APIBuilder} APIBuilder - The APIBuilder instance.
		 * @returns {Class} The connector class.
		 */
		create(APIBuilder) {
			const Connector = APIBuilder.Connector;
			const Capabilities = Connector.Capabilities;

			return Connector.extend({
				filename: path,
				capabilities: [
					Capabilities.ConnectsToADataSource,
					Capabilities.ValidatesConfiguration,
					// Capabilities.ContainsModels,
					Capabilities.GeneratesModels,
					Capabilities.CanCreate,
					Capabilities.CanRetrieve,
					Capabilities.CanUpdate,
					Capabilities.CanDelete
					// Capabilities.AuthenticatesThroughConnector
				],
				...lifecycle,
				...methods,
				...schema,
				...utility,
				...utilities,
				connect(next) {
					lifecycle.connect.call(this, dialect, next);
				}
			});
		}
	};
};
