/**
 * Gets the count of the model's instances.
 * @param {string} table The name of the database table.
 * @param {APIBuilder.Model} Model The model class being counted.
 * @param {object} options The query options.
 * @returns {number} The count of the items that matched the query.
 * @throws {Error}
 */
module.exports = async function count(table, Model, options = {}) {
	const primaryKeyColumn = this.getPrimaryKeyColumn(Model);
	const modelFields = Model.payloadKeys();
	const where = Model.translateKeysForPayload(options.where);

	// Build the query
	const dbQuery = this.connection(table)
		.withSchema(Model.getMeta('schema'))
		.count({ count: '*' });
	this.buildWhere(dbQuery, { where, primaryKeyColumn, modelFields });
	// Execute the query
	const results = await dbQuery;

	if (results) {
		const count = results.reduce((total, result) => {
			total += result.count;
			return total;
		}, 0);
		return count;
	}

	return 0;
};
