/**
 * Creates a new Model or Collection object.
 * @param {string} table The name of the database table.
 * @param {APIBuilder.Model} Model The model class being updated.
 * @param {Array<Object>|Object} [values] Attributes to set on the new model(s).
 * @returns {APIBuilder.Instance|null} The instance of the created item.
 * @throws {Error}
 */
module.exports = async function create(table, Model, values) {
	const payload = Model.instance(values, false).toPayload();
	const primaryKeyColumn = this.getPrimaryKeyColumn(Model);
	const columns = Model.payloadKeys();

	if (primaryKeyColumn) {
		columns.unshift(primaryKeyColumn);
		if (!this.getAutogenerated(Model)) {
			payload[primaryKeyColumn] = values[primaryKeyColumn];
		}
	}

	const results = await this.connection(table)
		.withSchema(Model.getMeta('schema'))
		.insert(payload)
		.returning(columns);

	// Seems like bug in https://knexjs.org/#Builder-returning - if a single column is requested it
	// is returning the bare value, as though it received a string.
	const row = results && (columns.length === 1 ? { [columns[0]]: results } : results[0]);
	if (row) {
		const instance = Model.instance(this.transformRow(row), true);
		if (primaryKeyColumn) {
			instance.setPrimaryKey(row[primaryKeyColumn]);
		}
		return instance;
	}
};
