/**
 * Deletes the model instance.
 * @param {string} table The name of the database table.
 * @param {APIBuilder.Model} Model The model class being updated.
 * @param {APIBuilder.Instance} instance Model instance.
 * @returns {APIBuilder.Instance|null} The item that was deleted.
 * @throws {Error}
 */
module.exports = async function deleteOne(table, Model, instance) {
	const primaryKeyColumn = this.getPrimaryKeyColumn(Model);

	if (!primaryKeyColumn) {
		throw new Error(`Can't find primary key column for ${table}`);
	}

	const result = await this.connection(table)
		.withSchema(Model.getMeta('schema'))
		.where({ [primaryKeyColumn]: instance.getPrimaryKey() })
		.del();

	if (result) {
		return instance;
	}
};
