/**
 * Queries for particular model records.
 * @param {string} table The name of the database table.
 * @param {APIBuilder.Model} Model The model class being queried.
 * @param {string} field The distinct field.
 * @param {ArrowQueryOptions} options Query options.
 * @returns {APIBuilder.Collection} The items fetched.
 * @throws {Error}
 */
module.exports = async function distinct(table, Model, field, options = {}) {
	const primaryKeyColumn = this.getPrimaryKeyColumn(Model);
	const where = Model.translateKeysForPayload(options.where);
	const modelFields = Model.payloadKeys();

	// Build the query
	const dbQuery = this.connection(table)
		.withSchema(Model.getMeta('schema'))
		.select()
		.distinct(field);
	this.buildWhere(dbQuery, { where, primaryKeyColumn, modelFields });
	this.buildOrder(dbQuery, {
		Model,
		primaryKeyColumn,
		modelFields,
		order: options.order,
		skip: options.skip,
		distinct: field
	});
	this.buildPagination(dbQuery, { skip: options.skip, limit: options.limit });

	// Execute the query
	const results = await dbQuery;

	return this.buildCollection(Model, results);
};
