/**
 * Finds all model instances.  A maximum of 1000 models are returned.
 * @param {string} table The name of the database table.
 * @param {APIBuilder.Model} Model The model class being updated.
 * @returns {APIBuilder.Collection} The items fetched.
 * @throws {Error}
 */
module.exports = async function findAll(table, Model) {
	const primaryKeyColumn = this.getPrimaryKeyColumn(Model);

	const dbQuery = this.connection(table)
		.withSchema(Model.getMeta('schema'))
		.limit(1000);
	if (primaryKeyColumn) {
		dbQuery.orderBy(primaryKeyColumn, 'asc');
	}
	const results = await dbQuery;

	return this.buildCollection(Model, results);
};
