/**
 * Finds a model instance using the primary key.
 * @param {string} table The name of the database table.
 * @param {APIBuilder.Model} Model The model class being updated.
 * @param {String} id ID of the model to find.
 * @returns {APIBuilder.Instance} The item fetched.
 * @throws {Error}
 */
module.exports = async function findByID(table, Model, id) {
	const primaryKeyColumn = this.getPrimaryKeyColumn(Model);

	if (!primaryKeyColumn) {
		throw new Error(`Can't find primary key column for ${table}`);
	}

	const results = await this.connection(table)
		.withSchema(Model.getMeta('schema'))
		.limit(1)
		.where({ [primaryKeyColumn]: id });

	if (!results.length) {
		return;
	}
	const row = results[0];
	const instance = Model.instance(this.transformRow(row), true);
	instance.setPrimaryKey(row[primaryKeyColumn]);
	return instance;
};
