/**
 * Queries for particular model records.
 * @param {string} table The name of the database table.
 * @param {APIBuilder.Model} Model The model class being updated.
 * @param {ArrowQueryOptions} options Query options.
 * @returns {APIBuilder.Collection} The items fetched.
 * @throws {Error}
 */
module.exports = async function query(table, Model, options = {}) {
	const primaryKeyColumn = this.getPrimaryKeyColumn(Model);
	const sel = Object.keys(Model.translateKeysForPayload(options.sel || {}));
	const unsel = Object.keys(Model.translateKeysForPayload(options.unsel || {}));
	const where = Model.translateKeysForPayload(options.where);
	const modelFields = Model.payloadKeys();

	// Execute the query
	const dbQuery = this.connection(table)
		.withSchema(Model.getMeta('schema'));
	this.buildSelect(dbQuery, { sel, unsel, primaryKeyColumn, modelFields });
	this.buildWhere(dbQuery, { where, primaryKeyColumn, modelFields });
	this.buildOrder(dbQuery, {
		Model, primaryKeyColumn, modelFields, order: options.order, skip: options.skip
	});
	this.buildPagination(dbQuery, { skip: options.skip, limit: options.limit });
	const results = await dbQuery;

	return this.buildCollection(Model, results);
};
