/**
 * Updates a Model instance.
 * @param {string} table The name of the database table
 * @param {APIBuilder.Model} Model The model class being updated.
 * @param {APIBuilder.Instance} instance Model instance to update.
 * @returns {APIBuilder.Instance} The item updated.
 * @throws {Error}
 */
module.exports = async function save(table, Model, instance) {
	const primaryKeyColumn = this.getPrimaryKeyColumn(Model);
	const primaryKey = instance.getPrimaryKey();
	const payload = instance.toPayload();
	const columns = [ primaryKeyColumn, ...Model.payloadKeys() ];

	if (!primaryKeyColumn) {
		throw new Error(`Can't find primary key column for ${table}`);
	}

	const dbQuery = this.connection(table)
		.withSchema(Model.getMeta('schema'))
		.limit(1)
		.where({ [primaryKeyColumn]: primaryKey })
		.update(payload)
		.returning(columns);

	const results = await dbQuery;

	const row = results && results[0];
	if (row) {
		const instance = Model.instance(this.transformRow(row), true);
		instance.setPrimaryKey(row[primaryKeyColumn]);
		return instance;
	}
};
