/**
 * Add the select fields to the query.
 * @param {object} query The query builder.
 * @param {object} params The params.
 * @param {number} params.modelFields The Model fields.
 * @param {number} params.primaryKeyColumn The primary key field.
 * @param {array} params.sel The fields to select (mutually exclusive with unsel).
 * @param {array} params.sel The fields to omit (mutually exclusive with sel).
 * @returns {object} The query builder.
 */
module.exports = function buildSelect(query, { modelFields, primaryKeyColumn, sel, unsel }) {
	// Error when providing fields that don't exist on the model
	for (const field of [ ...sel, ...unsel ]) {
		if (field !== primaryKeyColumn && !modelFields.includes(field)) {
			throw new Error(`Unknown field ${field}`);
		}
	}

	const queryKeys = new Set();

	if (sel.length) {
		primaryKeyColumn && queryKeys.add(primaryKeyColumn);
		modelFields
			.filter(field => sel.includes(field))
			.forEach(field => queryKeys.add(field));
	} else if (unsel.length) {
		const allFields = primaryKeyColumn ? [ primaryKeyColumn, ...modelFields ] : modelFields;
		allFields
			.filter(field => !unsel.includes(field))
			.forEach(unselField => queryKeys.add(unselField));
	} else {
		primaryKeyColumn && queryKeys.add(primaryKeyColumn);
		modelFields.forEach(field => queryKeys.add(field));
	}
	const fields = Array.from(queryKeys);
	return query.select(fields);
};
