/**
 * Fetches the if the table primary_key is auto_increment, based on its name.
 * @param {object} Model - model to use
 * @returns {boolean}
 */
module.exports = function getAutogenerated (Model) {
	// models generated from within the connector have PK details
	const primaryKeyDetails = Model.getMeta('primaryKeyDetails');
	if (primaryKeyDetails) {
		return !!primaryKeyDetails.autogenerated;
	}

	// models that reside on disk, may not have PK details, but we can obtain
	// these from the table schema
	const name = this.getTableName(Model);
	const primaryKeyColumn = this.getPrimaryKeyColumn(Model);
	if (primaryKeyColumn) {
		return this.schema.tables[name].primaryKey.autogenerated;
	}
};
